@@ -18,7 +18,11 @@ from firebolt.common.exception import (
     FireboltEngineError,
     InterfaceError,
 )
-from firebolt.common.urls import ACCOUNT_ENGINE_BY_NAME_URL, ACCOUNT_ENGINE_URL
+from firebolt.common.urls import (
+    ACCOUNT_ENGINE_BY_NAME_URL,
+    ACCOUNT_ENGINE_URL,
+    ACCOUNT_ENGINE_URL_BY_DATABASE_NAME,
+)
 from firebolt.common.util import fix_url_schema
 
 DEFAULT_TIMEOUT_SECONDS: int = 5
@@ -65,6 +69,36 @@ async def _resolve_engine_url(
             raise InterfaceError(f"Unable to retrieve engine endpoint: {e}.")
 
 
+async def _get_database_default_engine_url(
+    database: str,
+    auth: AuthTypes,
+    api_endpoint: str,
+    account_name: Optional[str] = None,
+) -> str:
+    async with AsyncClient(
+        auth=auth,
+        base_url=api_endpoint,
+        account_name=account_name,
+        api_endpoint=api_endpoint,
+    ) as client:
+        try:
+            account_id = await client.account_id
+            response = await client.get(
+                url=ACCOUNT_ENGINE_URL_BY_DATABASE_NAME.format(account_id=account_id),
+                params={"database_name": database},
+            )
+            response.raise_for_status()
+            return response.json()["engine_url"]
+        except (
+            JSONDecodeError,
+            RequestError,
+            RuntimeError,
+            HTTPStatusError,
+            KeyError,
+        ) as e:
+            raise InterfaceError(f"Unable to retrieve default engine endpoint: {e}.")
+
+
 def _validate_engine_name_and_url(
     engine_name: Optional[str], engine_url: Optional[str]
 ) -> None:
@@ -72,23 +106,35 @@ def _validate_engine_name_and_url(
         raise ConfigurationError(
             "Both engine_name and engine_url are provided. Provide only one to connect."
         )
-    if not engine_name and not engine_url:
-        raise ConfigurationError(
-            "Neither engine_name nor engine_url is provided. Provide one to connect."
-        )
 
 
 def _get_auth(
-    username: Optional[str], password: Optional[str], access_token: Optional[str]
-) -> AuthTypes:
+    username: Optional[str],
+    password: Optional[str],
+    access_token: Optional[str],
+    api_endpoint: str,
+    use_token_cache: bool,
+) -> Auth:
+    """Create Auth class based on provided credentials.
+
+    If access_token is provided, it's used for Auth creation.
+    Username and password are used otherwise.
+
+    Returns:
+        Auth: auth object
+
+    Raises:
+        ConfigurationError: Invalid combination of credentials provided
+
+    """
     if not access_token:
         if not username or not password:
             raise ConfigurationError(
                 "Neither username/password nor access_token are provided. Provide one"
                 " to authenticate"
             )
-        return (username, password)
-    elif username or password:
+        return Auth(username, password, api_endpoint, use_token_cache)
+    if username or password:
         raise ConfigurationError(
             "Either username/password and access_token are provided. Provide only one"
             " to authenticate"
@@ -106,21 +152,27 @@ def async_connect_factory(connection_class: Type) -> Callable:
         engine_url: Optional[str] = None,
         account_name: Optional[str] = None,
         api_endpoint: str = DEFAULT_API_URL,
+        use_token_cache: bool = True,
     ) -> Connection:
         """
         Connect to Firebolt database.
 
         Args:
-            database: name of the database to connect
-            username: user name to use for authentication
-            password: password to use for authentication
-            engine_name: Optional The name of the engine to connect to
-            engine_url: Optional. The engine endpoint to use
-            account_name: For customers with multiple accounts; if None uses default.
-            api_endpoint(optional): Firebolt API endpoint. Used for authentication.
+            database (str): Name of the database to connect
+            username (Optional[str]): User name to use for authentication
+            password (Optional[str]): Password to use for authentication
+            access_token (Optional[str]): Authentication token to use insead of
+                                          credentials
+            engine_name (Optional[str]): The name of the engine to connect to
+            engine_url (Optional[str]): The engine endpoint to use
+            account_name (Optional[str]): For customers with multiple accounts;
+                                          if None uses default.
+            api_endpoint (str): Firebolt API endpoint. Used for authentication.
+            use_token_cache (bool): Cached authentication token in filesystem.
+                                    Default: True
 
         Note:
-            Either `engine_name` or `engine_url` should be provided, but not both.
+            Providing both `engine_name` and `engine_url` would result in an error.
 
         """
         # These parameters are optional in function signature
@@ -130,13 +182,23 @@ def async_connect_factory(connection_class: Type) -> Callable:
             raise ConfigurationError("database name is required to connect.")
 
         _validate_engine_name_and_url(engine_name, engine_url)
-        auth = _get_auth(username, password, access_token)
+        auth = _get_auth(
+            username, password, access_token, api_endpoint, use_token_cache
+        )
         api_endpoint = fix_url_schema(api_endpoint)
 
         # Mypy checks, this should never happen
         assert database is not None
 
-        if engine_name:
+        if not engine_name and not engine_url:
+            engine_url = await _get_database_default_engine_url(
+                database=database,
+                auth=auth,
+                account_name=account_name,
+                api_endpoint=api_endpoint,
+            )
+
+        elif engine_name:
             engine_url = await _resolve_engine_url(
                 engine_name=engine_name,
                 auth=auth,
