@@ -26,9 +26,8 @@ class Cursor(AsyncBaseCursor):
         description: Information about a single result row
         rowcount: The number of rows produced by last query
         closed: True if connection is closed, False otherwise
-        arraysize: Read/Write,
-        specifies the number of rows to fetch at a time
-        with :py:func:`fetchmany` method
+        arraysize: Read/Write, specifies the number of rows to fetch at a time
+            with the :py:func:`fetchmany` method
     """
 
     __slots__ = AsyncBaseCursor.__slots__ + (
@@ -49,10 +48,11 @@ class Cursor(AsyncBaseCursor):
         query: str,
         parameters: Optional[Sequence[ParameterType]] = None,
         set_parameters: Optional[Dict] = None,
+        skip_parsing: bool = False,
     ) -> int:
         with self._query_lock.gen_wlock():
             return async_to_sync(super().execute, self._async_job_thread)(
-                query, parameters, set_parameters
+                query, parameters, set_parameters, skip_parsing
             )
 
     @wraps(AsyncBaseCursor.executemany)
