@@ -332,6 +332,7 @@ class Engine(FireboltBaseModel):
         auto_stop: Optional[int] = None,
         warmup: Optional[WarmupMethod] = None,
         description: Optional[str] = None,
+        use_spot: Optional[bool] = None,
     ) -> Engine:
         """
         update the engine, and returns an updated version of the engine, all parameters
@@ -354,14 +355,16 @@ class Engine(FireboltBaseModel):
         # Update engine settings
         engine_settings_params = {
             "engine_type": engine_type,
-            "auto_stop_delay_duration": f"{auto_stop * 60}s" if auto_stop else None,
+            "auto_stop_delay_duration": f"{auto_stop * 60}s"
+            if auto_stop is not None
+            else None,
             "warm_up": warmup,
         }
         self.settings = EngineSettings.default(**prune_dict(engine_settings_params))
 
         # Update the engine desired_revision if needed
         desired_revision = None
-        if (scale or spec) and self.latest_revision_key:
+        if (scale or spec or use_spot is not None) and self.latest_revision_key:
             rm = self._service.resource_manager
             desired_revision = rm.engine_revisions.get_by_key(self.latest_revision_key)
 
@@ -381,6 +384,9 @@ class Engine(FireboltBaseModel):
             if scale:
                 desired_revision.specification.db_compute_instances_count = scale
 
+            if use_spot is not None:
+                desired_revision.specification.db_compute_instances_use_spot = use_spot
+
         update_mask_paths = list(
             prune_dict(
                 {
